<?php
/*
Plugin Name: Simple Post Thumbnails Reloaded
Plugin URI: http://wordpress.org/extend/plugins/simple-post-thumbnails/ & Reloaded: 
Description: Easily add thumbnail images to your posts.
Version: 1.2.2_RU
Author: James Lao & Truper
Author URI: http://jameslao.com/ & Reloaded: http://wp-skins.info
*/

$wpURL = get_bloginfo('wpurl');
define("P75_THUMB_WEB", substr($wpURL, (strpos($wpURL, $_SERVER['HTTP_HOST'])+strlen($_SERVER['HTTP_HOST']))) . '/wp-content/thumbnails/');
unset($wpURL);
define("P75_THUMB_DIR", ABSPATH . "wp-content/thumbnails/"); // thumbnail directory

/**
 * Plugin activation.
 */
register_activation_hook(__FILE__, 'p75_sptActivate');

function p75_sptActivate()
{
	global $wpdb;
	
	// Set default thumbnail file type.
	add_option('p75_default_thumbnail_width', 200);
	add_option('p75_default_thumbnail_height', 150);
	add_option('p75_thumbnail_file_type', 'jpg');
	add_option('p75_spt_version', '1.2.1');
	
	// Migrate old thumbnails to new convention.
	$res = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "postmeta WHERE meta_key='_videothumb'");
	foreach ( $res as $row )
	{
		// Removes the URL path and saves only the file name.
		// i.e. http://yourwebsite.com/wp-content/thumbnails/34.png becomes 34.png
		preg_match("#/([\-a-zA-Z0-9]+\.(?:jpg|jpeg|png|gif))$#i", $row->meta_value, $matches);
		if ( $matches[1] )
			$wpdb->query("UPDATE " . $wpdb->prefix . "postmeta SET meta_value='" . $matches[1] . "' WHERE post_id='" . $row->post_id . "' AND meta_key='_videothumb'");
	}
	
	// Update legacy meta fields to the new ones.
	$wpdb->query("UPDATE " . $wpdb->prefix . "postmeta SET meta_key='_p75_thumbnail' WHERE meta_key='_videothumb'");
}

/**
 * Thumbnail directory check and GD extension check.
 */
if( !is_dir( P75_THUMB_DIR ) )
{
	if( !@mkdir( P75_THUMB_DIR ) )
	{
		function p75_WarningThumbnailFolder()
		{
			echo '<div class="updated fade"><p>Не смог создать директорию для изображений. Пожалуйста, создайте директорию &quot;thumbnails&quot; в директории &quot;wp-content&quot;.</p></div>';
		}
		add_action('admin_notices', 'p75_WarningThumbnailFolder');
	}
	if ( !function_exists("imagecreatetruecolor") )
	{
		function p75_WarningGD()
		{
			echo '<div class="updated fade"><p>The Simple Post Thumbnails plugin relies on the GD graphics extension to function. GD was not detected. Check with your host to make sure it is enabled.</p></div>';
		}
		add_action('admin_notices', 'p75_WarningGD');
	}
}

/**
 * Post admin hooks
 */
add_action('admin_menu', "p75_thumbnailAdminInit");
add_action('save_post', 'p75_saveThumb');

function p75_thumbnailAdminInit()
{
	if( function_exists("add_meta_box") )
		add_meta_box("p75-thumbnail-posting", "Управление новостным изображением", "p75_thumbnailPosting", "post", "advanced");
	
	add_options_page('Simple Post Thumbnails Options', 'Thumbnail Options', 8, 'thumbnailoptions', 'p75_thumbnailOptionsAdmin');
}

function p75_thumbnailOptionsAdmin()
{
	$fileType = get_option("p75_thumbnail_file_type");
?>
	<div class="wrap">
	<h2>Настройки плагина Simple Post Thumbnails</h2>
	
		<form method="post" action="options.php">
			<?php wp_nonce_field('update-options'); ?>
	
			<table class="form-table">
				<tr valign="top">
					<th style="white-space:nowrap;" scope="row"><label for="p75_default_thumbnail">Изображение по умолчанию:</label></th>
					<td><input id="p75_default_thumbnail" type="text" name="p75_default_thumbnail" value="<?php echo get_option('p75_default_thumbnail'); ?>" /></td>
					<td style="width:100%;">Ссылка на изображение, используемое по умолчанию.</td>
				</tr>
				
				<tr valign="top">
					<th style="white-space:nowrap;" scope="row"><label for="p75_thumbnail_file_type">Тип изображения:</label></th>
					<td>
						<select id="p75_thumbnail_file_type" name="p75_thumbnail_file_type">
							<option value="jpg"<?php if ( $fileType=="jpg" ) echo ' selected="selected"' ?>>JPEG</option>
							<option value="png"<?php if ( $fileType=="png" ) echo ' selected="selected"' ?>>PNG</option>
							<option value="gif"<?php if ( $fileType=="gif" ) echo ' selected="selected"' ?>>GIF</option>
						</select>
					</td>
					<td>Изображение будет конвертироваться в этот тип.</td>
				</tr>
				
				<tr valign="top">
					<th style="white-space:nowrap;" scope="row"><label for="p75_default_thumbnail_width">Ширина изображения:</label></th>
					<td><input id="p75_default_thumbnail_width" type="text" name="p75_default_thumbnail_width" value="<?php echo get_option('p75_default_thumbnail_width'); ?>" /></td>
					<td>Ширина изображения, используемая по умолчанию.</td>
				</tr>
				
				<tr valign="top">
					<th style="white-space:nowrap;" scope="row"><label for="p75_default_thumbnail_height">Высота изображения:</label></th>
					<td><input id="p75_default_thumbnail_height" type="text" name="p75_default_thumbnail_height" value="<?php echo get_option('p75_default_thumbnail_height'); ?>" /></td>
					<td>Высота изображения, используемая по умолчанию.</td>
				</tr>
			</table>
	
			<input type="hidden" name="action" value="обновить" />
			<input type="hidden" name="page_options" value="p75_default_thumbnail_width,p75_default_thumbnail_height,p75_default_thumbnail,p75_thumbnail_file_type" />
	
			<p class="submit">
				<input type="submit" class="button-primary" value="Сохранить изменения" />
			</p>
		</form>
	</div>

<?php
}

/**
 * Code for the meta box.
 */
function p75_thumbnailPosting()
{
	global $post_ID;
?>
	<script type="text/javascript">
		document.getElementById("post").setAttribute("enctype","multipart/form-data");
	</script>

	<?php
		$thumb = p75GetThumbnail($post_ID);
		if ( $thumb )
		{
	?>
	<div style="float: left; margin-right: 10px;">
		<img style="border: 1px solid #ccc; padding: 3px;" src="<?php echo $thumb; ?>" alt="Thumbnail preview" />
	</div>
	<?php
		}
		else
		{
	?>
	<div style="float: left; margin-right: 10px; width: 200px; height: 150px; line-height: 150px; border: solid 1px #ccc; text-align: center;">Просмотр изображений</div>
	<?php } ?>
	
	<div style="float: left;">
		<p>
			<label for="p75-thumb-url-upload">Вставьте ссылку на изображение:</label><br />
			<input style="width: 300px; margin-top:5px;" id="p75-thumb-url-upload" name="p75-thumb-url-upload" type="text" />
		</p>	
		<p>
			<p><label for="p75-thumbnail">Загрузить изображение вручную:</label><br />
			<input id="p75-thumbnail" type="file" name="p75-thumbnail" />
		</p>
		<p><input id="p75-thumb-delete" type="checkbox" name="p75-thumb-delete"> <label for="p75-thumb-delete">Удалить изображение</label></p>
		 
		<p style="margin:10px 0 0 0;"><input id="publish" class="button-primary" type="submit" value="Обновить новость" accesskey="p" tabindex="5" name="save"/></p>
	</div>
	
	<div class="clear"></div>
<?php
}

/**
 * Saves the thumbnail image as a meta field associated
 * with the current post. Runs when a post is saved.
 *
 * @param The post ID
 */
function p75_saveThumb( $postID )
{
	global $wpdb;

	// Get the correct post ID if revision.
	if ( $wpdb->get_var("SELECT post_type FROM $wpdb->posts WHERE ID=$postID")=='revision')
		$postID = $wpdb->get_var("SELECT post_parent FROM $wpdb->posts WHERE ID=$postID");

	if ( $_POST['p75-thumb-delete'] )
	{
		@unlink(P75_THUMB_DIR . get_post_meta($postID, '_p75_thumbnail', true));
		delete_post_meta($postID, '_p75_thumbnail');
	}
	elseif ( $_POST['p75-thumb-url-upload'] || !empty($_FILES['p75-thumbnail']['tmp_name']) )
	{
		if ( !empty($_FILES['p75-thumbnail']['name']) )
			preg_match("/(\.(?:jpg|jpeg|png|gif))$/i", $_FILES['p75-thumbnail']['name'], $matches);
		else
			preg_match("/(\.(?:jpg|jpeg|png|gif))$/i", $_POST['p75-thumb-url-upload'], $matches);
		
		$thumbFileName = $postID . strtolower($matches[0]);
   
		// Location of thumbnail on server.
		$loc = P75_THUMB_DIR . $thumbFileName;
		
		$thumbUploaded = false;
   
		if ( $_POST['p75-thumb-url-upload'] )
		{
			// Try just using fopen to download the image.
			if( ini_get('allow_url_fopen') )
			{
				copy($_POST['p75-thumb-url-upload'], $loc);
				$thumbUploaded = true;
			}
			else
			
			// If fopen doesn't work, try cURL.
			if( function_exists('curl_init') )
			{
				$ch = curl_init($_POST['p75-thumb-url-upload']);
				$fp = fopen($loc, "wb");
   
				$options = array(CURLOPT_FILE => $fp,
					CURLOPT_HEADER => 0,
					CURLOPT_FOLLOWLOCATION => 1,
					CURLOPT_TIMEOUT => 60);
				curl_setopt_array($ch, $options);
				
				curl_exec($ch);
				curl_close($ch);
   
				fclose($fp);
				$thumbUploaded = true;
			}
		}
		else
   
		// Attempt to move the uploaded thumbnail to the thumbnail directory.
		if ( !empty($_FILES['p75-thumbnail']['tmp_name']) && move_uploaded_file($_FILES['p75-thumbnail']['tmp_name'], $loc) )
			$thumbUploaded = true;
		
		if ( $thumbUploaded )
		{
			if ( !update_post_meta($postID, '_p75_thumbnail', $thumbFileName) )
				add_post_meta($postID, '_p75_thumbnail', $thumbFileName);
		}

	}
}

/**
 * Gets the thumbnail.
 *
 * @param $postID The post ID of the thumbnail.
 * @param $width The width of the thumbnail (optional)                            &zc=1
 * @param $height The height of the thumbnail (optional)
 * @param $fileType The file type of the thumbnail; jpg, png, or gif (optional)
 * @return The URL of the thumbnail.
 */
function p75GetThumbnail($postID, $width="", $height="", $fileType="")
{
	// Fetch default values for optional paramters if not specified.
	if ( empty($width) and empty($height) ){
		$width = "&w=" . get_option("p75_default_thumbnail_width");
		$height = "&h=" . get_option("p75_default_thumbnail_height");
		$zcrop='&zc=1';
	}
	if ( empty($width) ){
#		$width = get_option("p75_default_thumbnail_width");
		$height = "&h=" . $height;
		$zcrop='';
	}elseif ( empty($height) ){
#		$height = get_option("p75_default_thumbnail_height");
		$width = "&w=" . $width;
		$zcrop='';
	}else{
		$width = "&w=" . $width;
		$height = "&h=" . $height;
		$zcrop='&zc=1';
	}
	if ( empty($fileType) )
		$fileType = get_option("p75_thumbnail_file_type");

	if ( $thumb = get_post_meta($postID, '_p75_thumbnail', true) )
		return get_bloginfo('siteurl') . "/wp-content/plugins/simple-post-thumbnails/timthumb.php?src=" . P75_THUMB_WEB . $thumb . $width . $height . $zcrop ."&ft=" . $fileType;
	else
#		return get_option('p75_default_thumbnail');
		return get_bloginfo('siteurl') . "/wp-content/plugins/simple-post-thumbnails/timthumb.php?src=" . get_option('p75_default_thumbnail') . $width . $height . $zcrop ."&ft=" . $fileType;
}

/**
 * Gets the original image.
 *
 * @param $postID The post ID.
 * @return The web URL to the original image, false if does not exist.
 */
function p75GetOriginalImage($postID)
{
	if ( $pic = get_post_meta($postID, '_p75_thumbnail', true) )
		return P75_THUMB_WEB . $pic;
	else
		return false;
}

?>
